AccountModification class

Describes a modification to the configuration of Bring Your Own License (BYOL) for the specified account.

Constructors

AccountModification({String? dedicatedTenancyManagementCidrRange, DedicatedTenancySupportResultEnum? dedicatedTenancySupport, String? errorCode, String? errorMessage, DedicatedTenancyModificationStateEnum? modificationState, DateTime? startTime})
AccountModification.fromJson(Map<String, dynamic> json)
factory

Properties

dedicatedTenancyManagementCidrRange → String?
The IP address range, specified as an IPv4 CIDR block, for the management network interface used for the account.
final
dedicatedTenancySupport → DedicatedTenancySupportResultEnum?
The status of BYOL (whether BYOL is being enabled or disabled).
final
errorCode → String?
The error code that is returned if the configuration of BYOL cannot be modified.
final
errorMessage → String?
The text of the error message that is returned if the configuration of BYOL cannot be modified.
final
hashCode → int
The hash code for this object.
no setterinherited
modificationState → DedicatedTenancyModificationStateEnum?
The state of the modification to the configuration of BYOL.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
The timestamp when the modification of the BYOL configuration was started.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited