AssociateConnectionAliasResult class

Constructors

AssociateConnectionAliasResult({String? connectionIdentifier})
AssociateConnectionAliasResult.fromJson(Map<String, dynamic> json)
factory

Properties

connectionIdentifier → String?
The identifier of the connection alias association. You use the connection identifier in the DNS TXT record when you're configuring your DNS routing policies.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited