ConnectionAlias class

Describes a connection alias. Connection aliases are used for cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.

Constructors

ConnectionAlias({String? aliasId, List<ConnectionAliasAssociation>? associations, String? connectionString, String? ownerAccountId, ConnectionAliasState? state})
ConnectionAlias.fromJson(Map<String, dynamic> json)
factory

Properties

aliasId → String?
The identifier of the connection alias.
final
associations → List<ConnectionAliasAssociation>?
The association status of the connection alias.
final
connectionString → String?
The connection string specified for the connection alias. The connection string must be in the form of a fully qualified domain name (FQDN), such as www.example.com.
final
hashCode → int
The hash code for this object.
no setterinherited
ownerAccountId → String?
The identifier of the AWS account that owns the connection alias.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ConnectionAliasState?
The current state of the connection alias.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited