ConnectionAliasAssociation class

Describes a connection alias association that is used for cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.

Constructors

ConnectionAliasAssociation({String? associatedAccountId, AssociationStatus? associationStatus, String? connectionIdentifier, String? resourceId})
ConnectionAliasAssociation.fromJson(Map<String, dynamic> json)
factory

Properties

associatedAccountId → String?
The identifier of the AWS account that associated the connection alias with a directory.
final
associationStatus → AssociationStatus?
The association status of the connection alias.
final
connectionIdentifier → String?
The identifier of the connection alias association. You use the connection identifier in the DNS TXT record when you're configuring your DNS routing policies.
final
hashCode → int
The hash code for this object.
no setterinherited
resourceId → String?
The identifier of the directory associated with a connection alias.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited