ConnectionAliasPermission class

Describes the permissions for a connection alias. Connection aliases are used for cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.

Constructors

ConnectionAliasPermission({required bool allowAssociation, required String sharedAccountId})
ConnectionAliasPermission.fromJson(Map<String, dynamic> json)
factory

Properties

allowAssociation → bool
Indicates whether the specified AWS account is allowed to associate the connection alias with a directory.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedAccountId → String
The identifier of the AWS account that the connection alias is shared with.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited