CreateWorkspacesResult class

Constructors

CreateWorkspacesResult({List<FailedCreateWorkspaceRequest>? failedRequests, List<Workspace>? pendingRequests})
CreateWorkspacesResult.fromJson(Map<String, dynamic> json)
factory

Properties

failedRequests → List<FailedCreateWorkspaceRequest>?
Information about the WorkSpaces that could not be created.
final
hashCode → int
The hash code for this object.
no setterinherited
pendingRequests → List<Workspace>?
Information about the WorkSpaces that were created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited