DefaultWorkspaceCreationProperties class

Describes the default values that are used to create WorkSpaces. For more information, see Update Directory Details for Your WorkSpaces.

Constructors

DefaultWorkspaceCreationProperties({String? customSecurityGroupId, String? defaultOu, bool? enableInternetAccess, bool? enableMaintenanceMode, bool? enableWorkDocs, bool? userEnabledAsLocalAdministrator})
DefaultWorkspaceCreationProperties.fromJson(Map<String, dynamic> json)
factory

Properties

customSecurityGroupId → String?
The identifier of the default security group to apply to WorkSpaces when they are created. For more information, see Security Groups for Your WorkSpaces.
final
defaultOu → String?
The organizational unit (OU) in the directory for the WorkSpace machine accounts.
final
enableInternetAccess → bool?
Specifies whether to automatically assign an Elastic public IP address to WorkSpaces in this directory by default. If enabled, the Elastic public IP address allows outbound internet access from your WorkSpaces when you’re using an internet gateway in the Amazon VPC in which your WorkSpaces are located. If you're using a Network Address Translation (NAT) gateway for outbound internet access from your VPC, or if your WorkSpaces are in public subnets and you manually assign them Elastic IP addresses, you should disable this setting. This setting applies to new WorkSpaces that you launch or to existing WorkSpaces that you rebuild. For more information, see Configure a VPC for Amazon WorkSpaces.
final
enableMaintenanceMode → bool?
Specifies whether maintenance mode is enabled for WorkSpaces. For more information, see WorkSpace Maintenance.
final
enableWorkDocs → bool?
Specifies whether the directory is enabled for Amazon WorkDocs.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userEnabledAsLocalAdministrator → bool?
Specifies whether WorkSpace users are local administrators on their WorkSpaces.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited