DescribeAccountResult class

Constructors

DescribeAccountResult({String? dedicatedTenancyManagementCidrRange, DedicatedTenancySupportResultEnum? dedicatedTenancySupport})
DescribeAccountResult.fromJson(Map<String, dynamic> json)
factory

Properties

dedicatedTenancyManagementCidrRange → String?
The IP address range, specified as an IPv4 CIDR block, used for the management network interface.
final
dedicatedTenancySupport → DedicatedTenancySupportResultEnum?
The status of BYOL (whether BYOL is enabled or disabled).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited