DescribeClientPropertiesResult class

Constructors

DescribeClientPropertiesResult({List<ClientPropertiesResult>? clientPropertiesList})
DescribeClientPropertiesResult.fromJson(Map<String, dynamic> json)
factory

Properties

clientPropertiesList → List<ClientPropertiesResult>?
Information about the specified Amazon WorkSpaces clients.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited