DescribeConnectionAliasPermissionsResult class

Constructors

DescribeConnectionAliasPermissionsResult({String? aliasId, List<ConnectionAliasPermission>? connectionAliasPermissions, String? nextToken})
DescribeConnectionAliasPermissionsResult.fromJson(Map<String, dynamic> json)
factory

Properties

aliasId → String?
The identifier of the connection alias.
final
connectionAliasPermissions → List<ConnectionAliasPermission>?
The permissions associated with a connection alias.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token to use to retrieve the next set of results, or null if no more results are available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited