DescribeConnectionAliasesResult class

Constructors

DescribeConnectionAliasesResult({List<ConnectionAlias>? connectionAliases, String? nextToken})
DescribeConnectionAliasesResult.fromJson(Map<String, dynamic> json)
factory

Properties

connectionAliases → List<ConnectionAlias>?
Information about the specified connection aliases.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token to use to retrieve the next set of results, or null if no more results are available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited