DescribeWorkspaceSnapshotsResult class

Constructors

DescribeWorkspaceSnapshotsResult({List<Snapshot>? rebuildSnapshots, List<Snapshot>? restoreSnapshots})
DescribeWorkspaceSnapshotsResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
rebuildSnapshots → List<Snapshot>?
Information about the snapshots that can be used to rebuild a WorkSpace. These snapshots include the user volume.
final
restoreSnapshots → List<Snapshot>?
Information about the snapshots that can be used to restore a WorkSpace. These snapshots include both the root volume and the user volume.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited