DescribeWorkspacesResult class

Constructors

DescribeWorkspacesResult({String? nextToken, List<Workspace>? workspaces})
DescribeWorkspacesResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token to use to retrieve the next set of results, or null if no more results are available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workspaces → List<Workspace>?
Information about the WorkSpaces.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited