FailedCreateWorkspaceRequest class

Describes a WorkSpace that cannot be created.

Constructors

FailedCreateWorkspaceRequest({String? errorCode, String? errorMessage, WorkspaceRequest? workspaceRequest})
FailedCreateWorkspaceRequest.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
The error code that is returned if the WorkSpace cannot be created.
final
errorMessage → String?
The text of the error message that is returned if the WorkSpace cannot be created.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workspaceRequest → WorkspaceRequest?
Information about the WorkSpace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited