FailedWorkspaceChangeRequest class

Describes a WorkSpace that could not be rebooted. (RebootWorkspaces), rebuilt (RebuildWorkspaces), restored (RestoreWorkspace), terminated (TerminateWorkspaces), started (StartWorkspaces), or stopped (StopWorkspaces).

Constructors

FailedWorkspaceChangeRequest({String? errorCode, String? errorMessage, String? workspaceId})
FailedWorkspaceChangeRequest.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
The error code that is returned if the WorkSpace cannot be rebooted.
final
errorMessage → String?
The text of the error message that is returned if the WorkSpace cannot be rebooted.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workspaceId → String?
The identifier of the WorkSpace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited