SelfservicePermissions class

Describes the self-service permissions for a directory. For more information, see Enable Self-Service WorkSpace Management Capabilities for Your Users.

Constructors

SelfservicePermissions({ReconnectEnum? changeComputeType, ReconnectEnum? increaseVolumeSize, ReconnectEnum? rebuildWorkspace, ReconnectEnum? restartWorkspace, ReconnectEnum? switchRunningMode})
SelfservicePermissions.fromJson(Map<String, dynamic> json)
factory

Properties

changeComputeType → ReconnectEnum?
Specifies whether users can change the compute type (bundle) for their WorkSpace.
final
hashCode → int
The hash code for this object.
no setterinherited
increaseVolumeSize → ReconnectEnum?
Specifies whether users can increase the volume size of the drives on their WorkSpace.
final
rebuildWorkspace → ReconnectEnum?
Specifies whether users can rebuild the operating system of a WorkSpace to its original state.
final
restartWorkspace → ReconnectEnum?
Specifies whether users can restart their WorkSpace.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchRunningMode → ReconnectEnum?
Specifies whether users can switch the running mode of their WorkSpace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited