Workspace class

Describes a WorkSpace.

Constructors

Workspace({String? bundleId, String? computerName, String? directoryId, String? errorCode, String? errorMessage, String? ipAddress, List<ModificationState>? modificationStates, bool? rootVolumeEncryptionEnabled, WorkspaceState? state, String? subnetId, String? userName, bool? userVolumeEncryptionEnabled, String? volumeEncryptionKey, String? workspaceId, WorkspaceProperties? workspaceProperties})
Workspace.fromJson(Map<String, dynamic> json)
factory

Properties

bundleId → String?
The identifier of the bundle used to create the WorkSpace.
final
computerName → String?
The name of the WorkSpace, as seen by the operating system. The format of this name varies. For more information, see Launch a WorkSpace.
final
directoryId → String?
The identifier of the AWS Directory Service directory for the WorkSpace.
final
errorCode → String?
The error code that is returned if the WorkSpace cannot be created.
final
errorMessage → String?
The text of the error message that is returned if the WorkSpace cannot be created.
final
hashCode → int
The hash code for this object.
no setterinherited
ipAddress → String?
The IP address of the WorkSpace.
final
modificationStates → List<ModificationState>?
The modification states of the WorkSpace.
final
rootVolumeEncryptionEnabled → bool?
Indicates whether the data stored on the root volume is encrypted.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → WorkspaceState?
The operational state of the WorkSpace.
final
subnetId → String?
The identifier of the subnet for the WorkSpace.
final
userName → String?
The user for the WorkSpace.
final
userVolumeEncryptionEnabled → bool?
Indicates whether the data stored on the user volume is encrypted.
final
volumeEncryptionKey → String?
The symmetric AWS KMS customer master key (CMK) used to encrypt data stored on your WorkSpace. Amazon WorkSpaces does not support asymmetric CMKs.
final
workspaceId → String?
The identifier of the WorkSpace.
final
workspaceProperties → WorkspaceProperties?
The properties of the WorkSpace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited