WorkspaceAccessProperties class

The device types and operating systems that can be used to access a WorkSpace. For more information, see Amazon WorkSpaces Client Network Requirements.

Constructors

WorkspaceAccessProperties({AccessPropertyValue? deviceTypeAndroid, AccessPropertyValue? deviceTypeChromeOs, AccessPropertyValue? deviceTypeIos, AccessPropertyValue? deviceTypeOsx, AccessPropertyValue? deviceTypeWeb, AccessPropertyValue? deviceTypeWindows, AccessPropertyValue? deviceTypeZeroClient})
WorkspaceAccessProperties.fromJson(Map<String, dynamic> json)
factory

Properties

deviceTypeAndroid → AccessPropertyValue?
Indicates whether users can use Android devices to access their WorkSpaces.
final
deviceTypeChromeOs → AccessPropertyValue?
Indicates whether users can use Chromebooks to access their WorkSpaces.
final
deviceTypeIos → AccessPropertyValue?
Indicates whether users can use iOS devices to access their WorkSpaces.
final
deviceTypeOsx → AccessPropertyValue?
Indicates whether users can use macOS clients to access their WorkSpaces. To restrict WorkSpaces access to trusted devices (also known as managed devices) with valid certificates, specify a value of TRUST. For more information, see Restrict WorkSpaces Access to Trusted Devices.
final
deviceTypeWeb → AccessPropertyValue?
Indicates whether users can access their WorkSpaces through a web browser.
final
deviceTypeWindows → AccessPropertyValue?
Indicates whether users can use Windows clients to access their WorkSpaces. To restrict WorkSpaces access to trusted devices (also known as managed devices) with valid certificates, specify a value of TRUST. For more information, see Restrict WorkSpaces Access to Trusted Devices.
final
deviceTypeZeroClient → AccessPropertyValue?
Indicates whether users can use zero client devices to access their WorkSpaces.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited