WorkspaceBundle class

Describes a WorkSpace bundle.

Constructors

WorkspaceBundle({String? bundleId, ComputeType? computeType, String? description, String? imageId, DateTime? lastUpdatedTime, String? name, String? owner, RootStorage? rootStorage, UserStorage? userStorage})
WorkspaceBundle.fromJson(Map<String, dynamic> json)
factory

Properties

bundleId → String?
The bundle identifier.
final
computeType → ComputeType?
The compute type. For more information, see Amazon WorkSpaces Bundles.
final
description → String?
A description.
final
hashCode → int
The hash code for this object.
no setterinherited
imageId → String?
The image identifier of the bundle.
final
lastUpdatedTime → DateTime?
The last time that the bundle was updated.
final
name → String?
The name of the bundle.
final
owner → String?
The owner of the bundle. This is the account identifier of the owner, or AMAZON if the bundle is provided by AWS.
final
rootStorage → RootStorage?
The size of the root volume.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userStorage → UserStorage?
The size of the user storage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited