WorkspaceConnectionStatus class

Describes the connection status of a WorkSpace.

Constructors

WorkspaceConnectionStatus({ConnectionState? connectionState, DateTime? connectionStateCheckTimestamp, DateTime? lastKnownUserConnectionTimestamp, String? workspaceId})
WorkspaceConnectionStatus.fromJson(Map<String, dynamic> json)
factory

Properties

connectionState → ConnectionState?
The connection state of the WorkSpace. The connection state is unknown if the WorkSpace is stopped.
final
connectionStateCheckTimestamp → DateTime?
The timestamp of the connection status check.
final
hashCode → int
The hash code for this object.
no setterinherited
lastKnownUserConnectionTimestamp → DateTime?
The timestamp of the last known user connection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workspaceId → String?
The identifier of the WorkSpace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited