WorkspaceDirectory class

Describes a directory that is used with Amazon WorkSpaces.

Constructors

WorkspaceDirectory({String? alias, String? customerUserName, String? directoryId, String? directoryName, WorkspaceDirectoryType? directoryType, List<String>? dnsIpAddresses, String? iamRoleId, String? registrationCode, SelfservicePermissions? selfservicePermissions, WorkspaceDirectoryState? state, List<String>? subnetIds, Tenancy? tenancy, WorkspaceAccessProperties? workspaceAccessProperties, DefaultWorkspaceCreationProperties? workspaceCreationProperties, String? workspaceSecurityGroupId, List<String>? ipGroupIds})
WorkspaceDirectory.fromJson(Map<String, dynamic> json)
factory

Properties

alias → String?
The directory alias.
final
customerUserName → String?
The user name for the service account.
final
directoryId → String?
The directory identifier.
final
directoryName → String?
The name of the directory.
final
directoryType → WorkspaceDirectoryType?
The directory type.
final
dnsIpAddresses → List<String>?
The IP addresses of the DNS servers for the directory.
final
hashCode → int
The hash code for this object.
no setterinherited
iamRoleId → String?
The identifier of the IAM role. This is the role that allows Amazon WorkSpaces to make calls to other services, such as Amazon EC2, on your behalf.
final
ipGroupIds → List<String>?
The identifiers of the IP access control groups associated with the directory.
final
registrationCode → String?
The registration code for the directory. This is the code that users enter in their Amazon WorkSpaces client application to connect to the directory.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfservicePermissions → SelfservicePermissions?
The default self-service permissions for WorkSpaces in the directory.
final
state → WorkspaceDirectoryState?
The state of the directory's registration with Amazon WorkSpaces. After a directory is deregistered, the DEREGISTERED state is returned very briefly before the directory metadata is cleaned up, so this state is rarely returned. To confirm that a directory is deregistered, check for the directory ID by using DescribeWorkspaceDirectories. If the directory ID isn't returned, then the directory has been successfully deregistered.
final
subnetIds → List<String>?
The identifiers of the subnets used with the directory.
final
tenancy → Tenancy?
Specifies whether the directory is dedicated or shared. To use Bring Your Own License (BYOL), this value must be set to DEDICATED. For more information, see Bring Your Own Windows Desktop Images.
final
workspaceAccessProperties → WorkspaceAccessProperties?
The devices and operating systems that users can use to access WorkSpaces.
final
workspaceCreationProperties → DefaultWorkspaceCreationProperties?
The default creation properties for all WorkSpaces in the directory.
final
workspaceSecurityGroupId → String?
The identifier of the security group that is assigned to new WorkSpaces.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited