WorkspaceImage class

Describes a WorkSpace image.

Constructors

WorkspaceImage({DateTime? created, String? description, String? errorCode, String? errorMessage, String? imageId, String? name, OperatingSystem? operatingSystem, String? ownerAccountId, WorkspaceImageRequiredTenancy? requiredTenancy, WorkspaceImageState? state})
WorkspaceImage.fromJson(Map<String, dynamic> json)
factory

Properties

created → DateTime?
The date when the image was created. If the image has been shared, the AWS account that the image has been shared with sees the original creation date of the image.
final
description → String?
The description of the image.
final
errorCode → String?
The error code that is returned for the image.
final
errorMessage → String?
The text of the error message that is returned for the image.
final
hashCode → int
The hash code for this object.
no setterinherited
imageId → String?
The identifier of the image.
final
name → String?
The name of the image.
final
operatingSystem → OperatingSystem?
The operating system that the image is running.
final
ownerAccountId → String?
The identifier of the AWS account that owns the image.
final
requiredTenancy → WorkspaceImageRequiredTenancy?
Specifies whether the image is running on dedicated hardware. When Bring Your Own License (BYOL) is enabled, this value is set to DEDICATED. For more information, see Bring Your Own Windows Desktop Images.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → WorkspaceImageState?
The status of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited