WorkspaceProperties class

Describes a WorkSpace.

Constructors

WorkspaceProperties({Compute? computeTypeName, int? rootVolumeSizeGib, RunningMode? runningMode, int? runningModeAutoStopTimeoutInMinutes, int? userVolumeSizeGib})
WorkspaceProperties.fromJson(Map<String, dynamic> json)
factory

Properties

computeTypeName → Compute?
The compute type. For more information, see Amazon WorkSpaces Bundles.
final
hashCode → int
The hash code for this object.
no setterinherited
rootVolumeSizeGib → int?
The size of the root volume. For important information about how to modify the size of the root and user volumes, see Modify a WorkSpace.
final
runningMode → RunningMode?
The running mode. For more information, see Manage the WorkSpace Running Mode.
final
runningModeAutoStopTimeoutInMinutes → int?
The time after a user logs off when WorkSpaces are automatically stopped. Configured in 60-minute intervals.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userVolumeSizeGib → int?
The size of the user storage. For important information about how to modify the size of the root and user volumes, see Modify a WorkSpace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited