WorkspaceRequest class

Describes the information used to create a WorkSpace.

Constructors

WorkspaceRequest({required String bundleId, required String directoryId, required String userName, bool? rootVolumeEncryptionEnabled, List<Tag>? tags, bool? userVolumeEncryptionEnabled, String? volumeEncryptionKey, WorkspaceProperties? workspaceProperties})
WorkspaceRequest.fromJson(Map<String, dynamic> json)
factory

Properties

bundleId → String
The identifier of the bundle for the WorkSpace. You can use DescribeWorkspaceBundles to list the available bundles.
final
directoryId → String
The identifier of the AWS Directory Service directory for the WorkSpace. You can use DescribeWorkspaceDirectories to list the available directories.
final
hashCode → int
The hash code for this object.
no setterinherited
rootVolumeEncryptionEnabled → bool?
Indicates whether the data stored on the root volume is encrypted.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The tags for the WorkSpace.
final
userName → String
The user name of the user for the WorkSpace. This user name must exist in the AWS Directory Service directory for the WorkSpace.
final
userVolumeEncryptionEnabled → bool?
Indicates whether the data stored on the user volume is encrypted.
final
volumeEncryptionKey → String?
The symmetric AWS KMS customer master key (CMK) used to encrypt data stored on your WorkSpace. Amazon WorkSpaces does not support asymmetric CMKs.
final
workspaceProperties → WorkspaceProperties?
The WorkSpace properties.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited