WorkspacesIpGroup class

Describes an IP access control group.

Constructors

WorkspacesIpGroup({String? groupDesc, String? groupId, String? groupName, List<IpRuleItem>? userRules})
WorkspacesIpGroup.fromJson(Map<String, dynamic> json)
factory

Properties

groupDesc → String?
The description of the group.
final
groupId → String?
The identifier of the group.
final
groupName → String?
The name of the group.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userRules → List<IpRuleItem>?
The rules.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited